import 'package:flutter/material.dart';
import 'package:flutter_agnes/flutter_agnes.dart';
import 'package:flutter_agnes/src/widgets/dialogs/simple_dialog.dart';
import 'package:flutter_agnes/src/widgets/share/outline_button_widget.dart';
import 'package:asuka/asuka.dart' as asuka;

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Agnes Flutter',
      theme: ThemeData(
        primarySwatch: Colors.blue,
        accentColor: Colors.white
      ),
      builder: asuka.builder,
      home: MyHomePage(title: 'Agnes Flutter'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);
  final String title;
  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  TextEditingController textEditingController = TextEditingController();

  Future<MessageModel> getMessage() async {
    try {
      bool error = false;
      if (error) throw 'Simulação de erro!';

      await Future.delayed(const Duration(milliseconds: 2000));
      return MessageModel(code: 1, success: true, message: 'Sucesso!');
    } catch (e) {
      return MessageModel(code: -1, success: false, message: e);
    }
  }

  void _onPressed() async {
    bool result = await asuka.showDialog<bool>(
      barrierDismissible: false,
      builder: (context) => SimpleDialogFuture(
        showMessagePositive: true,
        loadingMessage: 'Aguarde...',
        future: getMessage(),
      ),
    );
    print('SimpleDialogFuture: ${result.toString()}');
  }

  void _onPressedButtonWidget() async {
    bool result = await asuka.showDialog<bool>(
        barrierDismissible: false,
        builder: (context) => SimpleDialogWidget(
              title: 'Message',
              messageModel: MessageModel(code: -1, success: false, message: 'Falha!'),
              onPressed: () => Navigator.pop(context),
            ));
    print('SimpleDialogFuture: ${result.toString()}');
  }

  Future<List<String>> getMonths() async{
    return ['January – Janeiro',
      'February – Fevereiro',
      'March – Março',
      'April – Abril',
      'May – Maio',
      'June – Junho',
      'July – Julho',
      'August – Agosto',
      'September – Setembro',
      'October – Outubro',
      'November – Novembro',
      'December – Dezembro'];
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: SingleChildScrollView(
        child: Container(
          padding: EdgeInsets.only(top: 20, left: 20, right: 20),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            children: <Widget>[
              OutlineButtonWidget(
                title: 'Simple Dialog Future',
                icon: Icons.check,
                width: double.maxFinite,
                onPressed: _onPressed,
              ),
              ButtonWidget(
                  label: 'Simple Dialog Widget',
                  borderRadius: 2,
                  width: double.maxFinite,
                  icon: Icons.check,
                  color: Theme.of(context).accentColor,
                  background: Theme.of(context).primaryColor,
                  onPressed: _onPressedButtonWidget),
              Row(
                children: [
                  Expanded(
                      child: TextFormFieldWidget(
                        icon: Icons.message,
                        controller: textEditingController,
                        labelText: 'Text clip oval',
                      )
                  ),
                  Expanded(
                      flex: 0,
                      child: ClipOvalWidget(
                          icon: Icons.check,
                          color: Colors.white,
                          background: Theme.of(context).primaryColor,
                          onTap: () {
                            setState(() {
                              textEditingController.text = 'Test clip oval';
                              FocusScope.of(context).requestFocus(new FocusNode());
                            });
                          }))],
              ),
              Card(
                elevation: 20,
                margin: EdgeInsets.only(top: 20),
                child: Container(
                  padding: EdgeInsets.only(top: 0),
                  height: 400,
                  child: Column(
                    children: [
                      Container(
                        padding: EdgeInsets.only(top: 10, bottom: 10),
                        child: Text('Example future builder widget',
                          style: TextStyle(fontSize: 16, fontWeight: FontWeight.bold),
                        ),
                      ),
                      Expanded(child: FutureBuilderWidget(
                        loadFuture: getMonths(),
                        builderWidget: (item, index){
                          return ListTile(
                            title: Text(item),
                          );
                        },
                      ),)
                    ],
                  )
                ),
              )
            ],
          ),
        ),
      )
    );
  }
}
