import 'package:flutter/material.dart';
import 'package:flutter_agnes/src/widgets/share/waiting_result.dart';

import '../../flutter_agnes.dart';

class SimpleDialogFuture<T> extends StatelessWidget {
  final Future<T> future;
  final String loadingMessage;
  final bool showMessagePositive;

  const SimpleDialogFuture({@required this.future, this.loadingMessage = 'Waiting...', this.showMessagePositive = false});

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      elevation: 0,
      backgroundColor: Colors.transparent,
      content: Container(
          child: FutureBuilder(
              future: future,
              builder: (context, snapshot) {
                switch (snapshot.connectionState) {
                  case ConnectionState.none:
                  case ConnectionState.waiting:
                    return WaitingResult(label: loadingMessage, color: Colors.white);
                  case ConnectionState.active:
                  case ConnectionState.done:
                    MessageModel messageModel = snapshot.data;
                    if (snapshot.hasData) {
                      if (messageModel.success) {
                        if (showMessagePositive)
                          return SimpleDialogWidget(
                            messageModel: messageModel,
                            onPressed: () => Navigator.pop(context, messageModel.success),
                          );
                        Navigator.pop(context, messageModel.success);
                        return Container();
                      }
                      return SimpleDialogWidget(
                        messageModel: messageModel,
                        onPressed: () => Navigator.pop(context, messageModel.success),
                      );
                    } else {
                      return SimpleDialogWidget(
                        messageModel: messageModel,
                        onPressed: () => Navigator.pop(context, messageModel.success),
                      );
                    }
                }
                return WaitingResult(label: loadingMessage, color: Colors.white);
              })),
    );
  }
}
