import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class TextFormFieldWidget extends StatelessWidget {

  final String labelText;
  final double height;
  final double width;
  final FormFieldValidator<String> validator;
  final TextEditingController controller;
  final IconData icon;
  final List<TextInputFormatter> inputFormatters;
  final int maxLength;
  final GestureTapCallback onTap;
  final TextInputType keyboardType;
  final bool enableInteractiveSelection;
  final ValueChanged<String> onChanged;
  final Widget suffixIcon;
  final FocusNode focusNode;
  final bool enabled;
  final ValueChanged<String> onFieldSubmitted;
  final TextAlign textAlign;
  final Color color;
  final Color colorIcon;
  final Color colorText;
  final bool obscureText;
  final bool readOnly;

  const TextFormFieldWidget(
      {this.labelText,
        this.height,
        this.width,
        this.validator,
        this.controller,
        this.icon = Icons.filter_list,
        this.inputFormatters,
        this.maxLength,
        this.onTap,
        this.keyboardType,
        this.enableInteractiveSelection = true,
        this.onChanged,
        this.suffixIcon,
        this.focusNode,
        this.enabled,
        this.onFieldSubmitted,
        this.color = Colors.grey,
        this.colorText = Colors.black,
        this.textAlign = TextAlign.start,
        this.obscureText = false,
        this.colorIcon = Colors.grey,
        this.readOnly = false});

  @override
  Widget build(BuildContext context) {
    return Container(
      height: height,
      width: width,
      child: TextFormField(
          readOnly: readOnly,
          textAlign: textAlign,
          textAlignVertical: TextAlignVertical.bottom,
          enabled: enabled,
          maxLength: maxLength,
          enableInteractiveSelection: enableInteractiveSelection,
          cursorColor: colorText,
          keyboardType: keyboardType,
          controller: controller,
          validator: validator,
          obscureText: obscureText,
          inputFormatters: inputFormatters,
          decoration: InputDecoration(
            icon: icon != null ? Icon(
              icon,
              color: colorIcon,
            ) : null,
            suffixIcon: suffixIcon,
            labelText: labelText,
            labelStyle: TextStyle(color: color, fontSize: 16),
            enabledBorder: UnderlineInputBorder(
              borderSide: BorderSide(
                color: color,
              ),
            ),
            focusedBorder: UnderlineInputBorder(
              borderSide: BorderSide(color: colorText),
            ),
          ),
          style: TextStyle(fontSize: 16, color: colorText),
          onTap: onTap,
          onChanged: onChanged,
          focusNode: focusNode,
          onFieldSubmitted: onFieldSubmitted
      ),
    );
  }
}
